@@ -41,6 +41,12 @@ class SimpleClient:
     def send(self, stream, data):
         self.ig.put(stream, data)
 
+    def subscribe(self, transform, callback):
+        self.reader.subscribe(transform, callback)
+
+    def unsubscribe(self, transform):
+        self.reader.unsubscribe(transform)
+
 
 ResourceTypes = ResourceTypes
 FieldTypes = FieldTypes
